@@ -86,7 +86,7 @@ def connect(url, motorcortex_types, param_tree, **kwargs):
     login_reply_msg = login_reply.get()
 
     motorcortex_msg = motorcortex_types.motorcortex()
-    if login_reply_msg.status == motorcortex_msg.OK:
+    if not login_reply_msg.status == motorcortex_msg.OK:
         raise RuntimeError("Login failed, status: %s" % login_reply_msg.status)
 
     # Requesting a parameter tree
